==> PhaseTypeR_1.0.0.tar.gz: PhaseTypeR/tests/testthat/_snaps/MDPH_functions.md <==
# test all outputs of the phase-type functions

    WAoAAAACAAQAAgACAwAAAAIOAAAAVD/FVVVVVVVUAAAAAAAAAAA/xVVVVVVVVAAAAAAAAAAA
    AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAP7mZmZmZmZg/0C2C2C2C2T+5mZmZmZmYAAAAAAAA
    AAA/pHrhR64Uej/ALYLYLYLZAAAAAAAAAAAAAAAAAAAAAD+QYk3S8an8P7znf/ZKfIw/pHrh
    R64UegAAAAAAAAAAP3o24uscQy0/tNC+ijO7IAAAAAAAAAAAAAAAAAAAAAA/ZPi1iONo8j+w
    F5tsJs7NP5BiTdLxqfwAAAAAAAAAAD/CDRMN+b3FP6hHlHK5ctwAAAAAAAAAAAAAAAAAAAAA
    P7A7nI5AoAI/ongrMmiTTj/CvTw2ETQDAAAAAAAAAAA/sfZB5ilqMD+cBPanNqN3P6WBBiTd
    LxkAAAAAAAAAAD+uWqx8fd2BP5VGOmW6Nlc/tAJLM9r43gAAAAAAAAAAP6P4GSajoAY/kCXM
    AB9Rgj+XOW0JF9a2P9Atgtgtgtk/pzJb+UxF9z+Ig/rdCrH5P6JYDDCP6sM/s2nQNp0Daj+k
    KjUBzx3KP4Kb8zf0pyA/o66QoaNTVj+XS8an752zP6JNQJH6Vc4/fECAjuYWFz+mdRMnehdz
    P3v0h/y5I6M/oWv8QFOBbj91chJKr27qP6Ai065XL6o/YMXrMTviLz+d73ZSUzjmP3BHbYW2
    ddQ/oh0jOxNdcD9EILPUrkKfP5tbuGOHbS8/aLbbHfgM+D+W0HeRLf2lPygnPjJqtlg/mMXA
    o91tjD9iwp3B3xmFP510My+oCL4/DPvkPIAOAj+WL0O1wKBiP1x7LfhTcIw/l7GxUrDpKz7x
    Y+9XgAhoP5RHIQdoRAM/VZ6ebEJTYD+Ycdf7VmYUPtTeUmkAChc/kkdPNJs38gAABAIAAAAB
    AAQACQAAAANkaW0AAAANAAAAAgAAAAQAAAAVAAAA/g==

---

    WAoAAAACAAQAAgACAwAAAAIOAAAAQD/FVVVVVVVUAAAAAAAAAAA/xVVVVVVVVAAAAAAAAAAA
    P8VVVVVVVVQAAAAAAAAAAD/FVVVVVVVUP7mZmZmZmZg/2tgtgtgtgj+5mZmZmZmYP8VVVVVV
    VVQ/weuFHrhR6D/hd3d3d3d4P7mZmZmZmZg/xVVVVVVVVD/D987ZFocoP+UUZ3ZAxwk/weuF
    HrhR7D/FVVVVVVVUP8TJhfBvaUQ/565/R4c+bT/B64UeuFHsP8VVVVVVVVQ/xR1oxpL26D/p
    sXK1DBhHP8P3ztkWhyw/xVVVVVVVVD/TlT3qRlpYP+s16/w3r3Q/w/fO2RaHLD/FVVVVVVVU
    P9ekJQ3Wglg/7F1ur144qj/TWoWHk92YP8VVVVVVVVQ/3CG1h2Dc5D/tPZZkl+3FP9YKpkwv
    g3w/xVVVVVVVVD/f7QsW8JiWP+3nyDfFv3g/2ws5GSZBsj/FVVVVVVVUP+E2Bx3ihks/7mj2
    l8a6BD/cfs/pt78eP9rYLYLYLYQ/4qks3XdKqz/uywaDOuTMP97J0W/JvHg/37KhkH9uXj/j
    69AtlDyHP+8VdlAat2k/4J/Rwf8TcT/gk679fzQdP+UQpDaz4eQ/7033UTiDlT/iByL0drTo
    P+DLmA14pmQ/5idj+rkZ+z/veNt1zeJzP+MJUC9cJ+I/4Nxd+KniRj/nFt+tS7PCAAAEAgAA
    AAEABAAJAAAAA2RpbQAAAA0AAAACAAAABAAAABAAAAD+

---

    WAoAAAACAAQAAgACAwAAAAIOAAAAKEAAAAAAAAAAQCAAAAAAAABAJgAAAAAAAEAYAAAAAAAA
    QAAAAAAAAABAIAAAAAAAAEAmAAAAAAAAQBgAAAAAAABAAAAAAAAAAEAkAAAAAAAAQCYAAAAA
    AABAHAAAAAAAAEAIAAAAAAAAQCYAAAAAAABAKAAAAAAAAEAgAAAAAAAAQAgAAAAAAABAKgAA
    AAAAAEAqAAAAAAAAQCQAAAAAAABAEAAAAAAAAEAuAAAAAAAAQDYAAAAAAABAKAAAAAAAAEAU
    AAAAAAAAQDIAAAAAAABANwAAAAAAAEAsAAAAAAAAQBgAAAAAAABANQAAAAAAAEBAAAAAAAAA
    QDAAAAAAAABAHAAAAAAAAEA6AAAAAAAAQEEAAAAAAABANAAAAAAAAEAiAAAAAAAAQECAAAAA
    AABARoAAAAAAAEA6AAAAAAAAAAAEAgAAAAEABAAJAAAAA2RpbQAAAA0AAAACAAAABAAAAAoA
    AAD+

==> PhaseTypeR_1.0.3.tar.gz: PhaseTypeR/tests/testthat/_snaps/MDPH_functions.md <==
# test all outputs of the phase-type functions

    WAoAAAACAAQBAQACAwAAAAIOAAAAVD/FVVVVVVVUAAAAAAAAAAA/xVVVVVVVVAAAAAAAAAAA
    AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAP7mZmZmZmZg/0C2C2C2C2T+5mZmZmZmYAAAAAAAA
    AAA/pHrhR64Uej/ALYLYLYLZAAAAAAAAAAAAAAAAAAAAAD+QYk3S8an8P7znf/ZKfIw/pHrh
    R64UegAAAAAAAAAAP3o24uscQy0/tNC+ijO7IAAAAAAAAAAAAAAAAAAAAAA/ZPi1iONo8j+w
    F5tsJs7NP5BiTdLxqfwAAAAAAAAAAD/CDRMN+b3FP6hHlHK5ctwAAAAAAAAAAAAAAAAAAAAA
    P7A7nI5AoAI/ongrMmiTTj/CvTw2ETQDAAAAAAAAAAA/sfZB5ilqMD+cBPanNqN3P6WBBiTd
    LxkAAAAAAAAAAD+uWqx8fd2BP5VGOmW6Nlc/tAJLM9r43gAAAAAAAAAAP6P4GSajoAY/kCXM
    AB9Rgj+XOW0JF9a2P9Atgtgtgtk/pzJb+UxF9z+Ig/rdCrH5P6JYDDCP6sM/s2nQNp0Daj+k
    KjUBzx3KP4Kb8zf0pyA/o66QoaNTVj+XS8an752zP6JNQJH6Vc4/fECAjuYWFz+mdRMnehdz
    P3v0h/y5I6M/oWv8QFOBbj91chJKr27qP6Ai065XL6o/YMXrMTviLz+d73ZSUzjmP3BHbYW2
    ddQ/oh0jOxNdcD9EILPUrkKfP5tbuGOHbS8/aLbbHfgM+D+W0HeRLf2lPygnPjJqtlg/mMXA
    o91tjD9iwp3B3xmFP510My+oCL4/DPvkPIAOAj+WL0O1wKBiP1x7LfhTcIw/l7GxUrDpKz7x
    Y+9XgAhoP5RHIQdoRAM/VZ6ebEJTYD+Ycdf7VmYUPtTeUmkAChc/kkdPNJs38gAABAIAAAAB
    AAQACQAAAANkaW0AAAANAAAAAgAAAAQAAAAVAAAA/g==

---

    WAoAAAACAAQBAQACAwAAAAIOAAAAQD/FVVVVVVVUAAAAAAAAAAA/xVVVVVVVVAAAAAAAAAAA
    P8VVVVVVVVQAAAAAAAAAAD/FVVVVVVVUP7mZmZmZmZg/2tgtgtgtgj+5mZmZmZmYP8VVVVVV
    VVQ/weuFHrhR6D/hd3d3d3d4P7mZmZmZmZg/xVVVVVVVVD/D987ZFocoP+UUZ3ZAxwk/weuF
    HrhR7D/FVVVVVVVUP8TJhfBvaUQ/565/R4c+bT/B64UeuFHsP8VVVVVVVVQ/xR1oxpL26D/p
    sXK1DBhHP8P3ztkWhyw/xVVVVVVVVD/TlT3qRlpYP+s16/w3r3Q/w/fO2RaHLD/FVVVVVVVU
    P9ekJQ3Wglg/7F1ur144qj/TWoWHk92YP8VVVVVVVVQ/3CG1h2Dc5D/tPZZkl+3FP9YKpkwv
    g3w/xVVVVVVVVD/f7QsW8JiWP+3nyDfFv3g/2ws5GSZBsj/FVVVVVVVUP+E2Bx3ihks/7mj2
    l8a6BD/cfs/pt78eP9rYLYLYLYQ/4qks3XdKqz/uywaDOuTMP97J0W/JvHg/37KhkH9uXj/j
    69AtlDyHP+8VdlAat2k/4J/Rwf8TcT/gk679fzQdP+UQpDaz4eQ/7033UTiDlT/iByL0drTo
    P+DLmA14pmQ/5idj+rkZ+z/veNt1zeJzP+MJUC9cJ+I/4Nxd+KniRj/nFt+tS7PCAAAEAgAA
    AAEABAAJAAAAA2RpbQAAAA0AAAACAAAABAAAABAAAAD+

---

    WAoAAAACAAQBAQACAwAAAAIOAAAAKEAAAAAAAAAAQCAAAAAAAABAJgAAAAAAAEAYAAAAAAAA
    QAAAAAAAAABAIAAAAAAAAEAmAAAAAAAAQBgAAAAAAABAAAAAAAAAAEAkAAAAAAAAQCYAAAAA
    AABAHAAAAAAAAEAIAAAAAAAAQCYAAAAAAABAKAAAAAAAAEAgAAAAAAAAQAgAAAAAAABAKgAA
    AAAAAEAqAAAAAAAAQCQAAAAAAABAEAAAAAAAAEAuAAAAAAAAQDYAAAAAAABAKAAAAAAAAEAU
    AAAAAAAAQDIAAAAAAABANwAAAAAAAEAsAAAAAAAAQBgAAAAAAABANQAAAAAAAEBAAAAAAAAA
    QDAAAAAAAABAHAAAAAAAAEA6AAAAAAAAQEEAAAAAAABANAAAAAAAAEAiAAAAAAAAQECAAAAA
    AABARoAAAAAAAEA6AAAAAAAAAAAEAgAAAAEABAAJAAAAA2RpbQAAAA0AAAACAAAABAAAAAoA
    AAD+
